namespace efl { namespace event { 
inline ::efl::eolian::return_traits< ::efl::input::Device>::type Input::device_get() const
{
    ::Efl_Input_Device* __return_value =  ::efl_event_device_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::input::Device>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Input::device_set( ::efl::eolian::in_traits< ::efl::input::Device>::type dev) const
{
    ::efl_event_device_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Input_Device*,  ::efl::eolian::in_traits< ::efl::input::Device>::type>(dev));
}
inline ::efl::eolian::return_traits<Efl_Event_Flags>::type Input::event_flags_get() const
{
   Efl_Event_Flags __return_value =  ::efl_event_flags_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Event_Flags>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Input::event_flags_set( ::efl::eolian::in_traits<Efl_Event_Flags>::type flags) const
{
    ::efl_event_flags_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Event_Flags,  ::efl::eolian::in_traits<Efl_Event_Flags>::type>(flags));
}
inline ::efl::eolian::return_traits<bool>::type Input::processed_get() const
{
   Eina_Bool __return_value =  ::efl_event_processed_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Input::processed_set( ::efl::eolian::in_traits<bool>::type val) const
{
    ::efl_event_processed_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(val));
}
inline ::efl::eolian::return_traits<bool>::type Input::scrolling_get() const
{
   Eina_Bool __return_value =  ::efl_event_scrolling_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Input::scrolling_set( ::efl::eolian::in_traits<bool>::type val) const
{
    ::efl_event_scrolling_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(val));
}
inline ::efl::eolian::return_traits<bool>::type Input::fake_get() const
{
   Eina_Bool __return_value =  ::efl_event_fake_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
} } 
namespace eo_cxx {
namespace efl { namespace event { 
inline ::efl::eolian::return_traits< ::efl::input::Device>::type Input::device_get() const
{
    ::Efl_Input_Device* __return_value =  ::efl_event_device_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::input::Device>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Input::device_set( ::efl::eolian::in_traits< ::efl::input::Device>::type dev) const
{
    ::efl_event_device_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Input_Device*,  ::efl::eolian::in_traits< ::efl::input::Device>::type>(dev));
}
inline ::efl::eolian::return_traits<Efl_Event_Flags>::type Input::event_flags_get() const
{
   Efl_Event_Flags __return_value =  ::efl_event_flags_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Event_Flags>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Input::event_flags_set( ::efl::eolian::in_traits<Efl_Event_Flags>::type flags) const
{
    ::efl_event_flags_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Event_Flags,  ::efl::eolian::in_traits<Efl_Event_Flags>::type>(flags));
}
inline ::efl::eolian::return_traits<bool>::type Input::processed_get() const
{
   Eina_Bool __return_value =  ::efl_event_processed_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Input::processed_set( ::efl::eolian::in_traits<bool>::type val) const
{
    ::efl_event_processed_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(val));
}
inline ::efl::eolian::return_traits<bool>::type Input::scrolling_get() const
{
   Eina_Bool __return_value =  ::efl_event_scrolling_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Input::scrolling_set( ::efl::eolian::in_traits<bool>::type val) const
{
    ::efl_event_scrolling_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(val));
}
inline ::efl::eolian::return_traits<bool>::type Input::fake_get() const
{
   Eina_Bool __return_value =  ::efl_event_fake_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline efl::event::Input::operator ::efl::event::Input() const { return *static_cast< ::efl::event::Input const*>(static_cast<void const*>(this)); }
inline efl::event::Input::operator ::efl::event::Input&() { return *static_cast< ::efl::event::Input*>(static_cast<void*>(this)); }
inline efl::event::Input::operator ::efl::event::Input const&() const { return *static_cast< ::efl::event::Input const*>(static_cast<void const*>(this)); }
} } }

